| OPC_Trial.simulation | R Documentation |
Operation characteristic table for null scenario using main model.
OPC_Trial.simulation
A data frame with 1 rows and 8 variables:
Type.I.Error.or.PowerPower
BiasTreatment effect bias for treatment 1
rMSERooted mean squared error for treatment effect 1
N.per.arm.1Mean total number of patient allocated to control
N.per.arm.2Mean total number of patient allocated to treatment 1
Survive.per.arm.1Mean total number of patient allocated to control
Survive.per.arm.2Mean total number of patient survived when using treatment 1
NMean total number of patient in a trial
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.