| dataloginformd | R Documentation |
Details of grid including famliy wise error rate of a cutoff value, the cutoff value and the square of cutoff value for modelling and prediction
dataloginformd
A data frame with 24 rows and 3 variables:
tpIEFWER
cutoffCutoff value
cutoff2Square of cutoff value
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.